CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
44 lines
1.3 KiB
Plaintext
44 lines
1.3 KiB
Plaintext
// RUN: %clang_cc1 -std=c++11 -triple nvptx64-nvidia-cuda -fsyntax-only \
|
|
// RUN: -fcuda-is-device -verify -verify-ignore-unexpected=note %s
|
|
// RUN: %clang_cc1 -std=c++11 -triple x86_64-unknown-linux-gnu -fsyntax-only \
|
|
// RUN: -verify -verify-ignore-unexpected=note %s
|
|
|
|
#include "Inputs/cuda.h"
|
|
|
|
struct In { In() = default; };
|
|
struct InD { __device__ InD() = default; };
|
|
struct InH { __host__ InH() = default; };
|
|
struct InHD { __host__ __device__ InHD() = default; };
|
|
|
|
struct Out { Out(); };
|
|
struct OutD { __device__ OutD(); };
|
|
struct OutH { __host__ OutH(); };
|
|
struct OutHD { __host__ __device__ OutHD(); };
|
|
|
|
Out::Out() = default;
|
|
__device__ OutD::OutD() = default;
|
|
__host__ OutH::OutH() = default;
|
|
__host__ __device__ OutHD::OutHD() = default;
|
|
|
|
__device__ void fd() {
|
|
In in;
|
|
InD ind;
|
|
InH inh; // expected-error{{no matching constructor for initialization of 'InH'}}
|
|
InHD inhd;
|
|
Out out; // expected-error{{no matching constructor for initialization of 'Out'}}
|
|
OutD outd;
|
|
OutH outh; // expected-error{{no matching constructor for initialization of 'OutH'}}
|
|
OutHD outhd;
|
|
}
|
|
|
|
__host__ void fh() {
|
|
In in;
|
|
InD ind; // expected-error{{no matching constructor for initialization of 'InD'}}
|
|
InH inh;
|
|
InHD inhd;
|
|
Out out;
|
|
OutD outd; // expected-error{{no matching constructor for initialization of 'OutD'}}
|
|
OutH outh;
|
|
OutHD outhd;
|
|
}
|